==> mongodb-src-r2.5.5.zip: mongodb-src-r2.5.5/src/mongo/util/fail_point_registry.cpp <==
/*
 *    Copyright (C) 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#include "mongo/util/fail_point_registry.h"

#include "mongo/db/commands.h"
#include "mongo/util/map_util.h"
#include "mongo/util/mongoutils/str.h"

using mongoutils::str::stream;

namespace mongo {
    FailPointRegistry::FailPointRegistry(): _frozen(false) {
    }

    Status FailPointRegistry::addFailPoint(const string& name,
            FailPoint* failPoint) {
        if (_frozen) {
            return Status(ErrorCodes::CannotMutateObject, "Registry is already frozen");
        }

        if (_fpMap.count(name) > 0) {
            return Status(ErrorCodes::DuplicateKey,
                    stream() << "Fail point already registered: " << name);
        }

        _fpMap.insert(make_pair(name, failPoint));
        return Status::OK();
    }

    FailPoint* FailPointRegistry::getFailPoint(const string& name) const {
        return mapFindWithDefault(_fpMap, name, reinterpret_cast<FailPoint *>(NULL));
    }

    void FailPointRegistry::freeze() {
        _frozen = true;
    }
}

==> mongodb-src-r3.1.3.zip: mongodb-src-r3.1.3/src/mongo/util/fail_point_registry.cpp <==
/*
 *    Copyright (C) 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#include "mongo/util/fail_point_registry.h"

#include "mongo/util/map_util.h"
#include "mongo/util/mongoutils/str.h"

using mongoutils::str::stream;

namespace mongo {

    using std::string;

    FailPointRegistry::FailPointRegistry(): _frozen(false) {
    }

    Status FailPointRegistry::addFailPoint(const string& name,
            FailPoint* failPoint) {
        if (_frozen) {
            return Status(ErrorCodes::CannotMutateObject, "Registry is already frozen");
        }

        if (_fpMap.count(name) > 0) {
            return Status(ErrorCodes::DuplicateKey,
                    stream() << "Fail point already registered: " << name);
        }

        _fpMap.insert(make_pair(name, failPoint));
        return Status::OK();
    }

    FailPoint* FailPointRegistry::getFailPoint(const string& name) const {
        return mapFindWithDefault(_fpMap, name, static_cast<FailPoint*>(NULL));
    }

    void FailPointRegistry::freeze() {
        _frozen = true;
    }
}
